/*
  This file is part of mpro.

  mpro is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  dolt is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with dolt; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

  $Id: bounce-off-walls.cpp,v 1.4 2006/01/30 05:38:40 beevek Exp $

  Copyright (c) 2006 Kris Beevers
*/

/*!
  \file bounce-off-walls.cpp
  \author Kris Beevers (beevek@cs.rpi.edu)
  \version $Id: bounce-off-walls.cpp,v 1.4 2006/01/30 05:38:40 beevek Exp $

  \brief Move forward until an IR sensor detects something nearby,
  then turn away and repeat.
 */

#include <mproclient.h>
#include <stdio.h>
#ifndef _WIN32
  #include <math.h>   // for M_PI
#else
  #define M_PI 3.1415926535897932384626433833
#endif

int main(int argc, char **argv)
{
  char *host = "localhost";
  if(argc > 1)
    host = argv[1];

  if(mpro_connect(host) < 0) {
    printf("Can't connect to %s!\n", host);
    return 1;
  }

  // if host is a simulator, reset the simulation
  mpro_reset_sim();

  float ranges[MPRO_NUM_IR];
  int min, i;

  /***************************************************
   This program isn't finished yet!
   ***************************************************/

  while(1) {
    mpro_get_all_ir(ranges); // get ranges from all IR sensors

    // find the sensor reporting the minimum range
    printf("%f ", ranges[0]);
    for(min = 0, i = 1; i < MPRO_NUM_IR; ++i) {
      printf("%f ", ranges[i]);
      if(ranges[i] < ranges[min])
	min = i;
    }
    printf("\n");

#if 0
    // if it's close enough, turn away
    if(ranges[min] < 0.3) {
      printf("min %d, %f\n", min, ranges[min]);
      printf("rotating %f\n", float(min) * 2.0*M_PI/float(MPRO_NUM_IR));
      mpro_rotate(float(min) * 2.0*M_PI/float(MPRO_NUM_IR));

      /*
      if(min >= 0 && min <= 8) {
	printf("rotating %f\n", float(min)*2.0*M_PI/MPRO_NUM_IR - M_PI);
	mpro_rotate(M_PI - float(min)*2.0*M_PI/MPRO_NUM_IR);
      } else {
	printf("rotating %f\n", M_PI - float(MPRO_NUM_IR-min)*2.0*M_PI/MPRO_NUM_IR);
	mpro_rotate(float(MPRO_NUM_IR-min)*2.0*M_PI/MPRO_NUM_IR - M_PI);
      }
      */
    }
#endif

    mpro_set_velocity(0.25, 0); // start moving forward at 0.25 m/sec
  }

  mpro_stop(); // should never get here
  return 0;
}
