/*
  This file is part of mpro.

  mpro is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  dolt is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with dolt; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

  $Id: move-until-bump.cpp,v 1.5 2006/01/30 05:38:40 beevek Exp $

  Copyright (c) 2006 Kris Beevers
*/

/*!
  \file move-until-bump.cpp
  \author Kris Beevers (beevek@cs.rpi.edu)
  \version $Id: move-until-bump.cpp,v 1.5 2006/01/30 05:38:40 beevek Exp $

  \brief A simple example program that backs the robot up, rotates it
  450 degrees, and then moves forward until the robot bumps into
  something.
 */

#include <mproclient.h>
#include <stdio.h>
#ifndef _WIN32
  #include <math.h>   // for M_PI
#else
  #define M_PI 3.1415926535897932384626433833
#endif

int main(int argc, char **argv)
{
  char *host = "localhost";
  if(argc > 1)
    host = argv[1];

  if(mpro_connect(host) < 0) {
    printf("Can't connect to %s!\n", host);
    return 1;
  }

  // if host is a simulator, reset the simulation
  mpro_reset_sim();

  mpro_translate(-1.0);      // move backward 1 meter
  mpro_rotate(5.0*M_PI/2.0); // rotate 450 degrees
  mpro_set_velocity(0.4, 0); // start moving forward at 0.4 m/sec

  bool toggles[MPRO_NUM_BUMP];
  while(1) {
    // ask for the values of all the bump sensors
    mpro_get_all_bump(toggles);

    // are any of them on?
    for(int i = 0; i < MPRO_NUM_BUMP; ++i)
      if(toggles[i]) {
	printf("Bump sensor %d is on!\n", i);
	mpro_stop(); // stop the robot
	return 0;
      }
  }

  return 0;
}
