/*
  This file is part of mpro.

  mpro is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  dolt is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with dolt; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

  $Id: move-until-ir.cpp,v 1.3 2006/01/30 05:38:40 beevek Exp $

  Copyright (c) 2006 Kris Beevers
*/

/*!
  \file move-until-ir.cpp
  \author Kris Beevers (beevek@cs.rpi.edu)
  \version $Id: move-until-ir.cpp,v 1.3 2006/01/30 05:38:40 beevek Exp $

  \brief Move forward until the front IR sensor sees something within
  0.25m.
 */

#include <mproclient.h>
#include <stdio.h>

int main(int argc, char **argv)
{
  char *host = "localhost";
  if(argc > 1)
    host = argv[1];

  if(mpro_connect(host) < 0) {
    printf("Can't connect to %s!\n", host);
    return 1;
  }

  // if host is a simulator, reset the simulation
  mpro_reset_sim();

  mpro_set_velocity(0.25, 0); // start moving forward at 0.25 m/sec

  float range;
  do {
    mpro_get_ir(0, &range); // get the range from IR 0
  } while(range > 0.25);

  mpro_stop();

  return 0;
}
