/*
  This file is part of mpro.

  mpro is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  dolt is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with dolt; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

  $Id: mproserver.h,v 1.1.1.1 2006/01/26 05:47:48 beevek Exp $

  Copyright (c) 2006 Kris Beevers
*/

/*!
  \file mproserver.h
  \author Kris Beevers (beevek@cs.rpi.edu)
  \version $Id: mproserver.h,v 1.1.1.1 2006/01/26 05:47:48 beevek Exp $

  \brief Magellan Pro server basics.  A server (simulator, robot
  controller) must implement all of the procedures in mproclient.h,
  which will be called by the server listener as appropriate.  (Note
  that the actual client library also implements those procedures, and
  so no program can be both a server and a client.)
 */

#ifndef _MPROSERVER_H
#define _MPROSERVER_H

#include "protocol.h"
#include "mproclient.h" // for prototypes

#ifdef __cplusplus
extern "C" {
#endif

/*!
  \brief Start up the server.  (Does not enter a serving loop, merely
  performs initialization.)
  \param type Type of server (robot control or simulator)
  \param port Network port on which the server will listen for
  connections.  Note that this constructor doesn't actually start
  listening on the port.
  \return >= 0 on success; < 0 on failure (see errno)
*/
int mpro_server_start(server_type_t type = CONTROL, uint16_t port = MPRO_PORT);

/*!
  \brief Shut down the listener if it is listening.
  \return >= 0 on success; < 0 on failure (see errno)
*/
int mpro_server_stop();

/*!

  \brief Specify a function to be called repeatedly to do some
  periodic processing on the server.
  \param process A function that performs periodic processing
  \param ms The number of milliseconds in between calls to the
  processing function
  \return >= 0 on success; < 0 on failure (see errno)
*/
int mpro_server_process_func(int (*process)(void), uint32_t ms);

/*!
  \brief In an infinite loop, wait for requests and handle them
  appropriately.
  \return < 0 on failure (see errno); otherwise, never returns
  \sa mpro_serve_pending
*/
int mpro_serve_forever();

#ifdef __cplusplus
}
#endif

#endif // _MPROSERVER_H
