/*
  This file is part of mpro.

  mpro is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  dolt is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with dolt; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

  $Id: mproshutdown.cpp,v 1.2 2006/02/09 01:42:21 beevek Exp $

  Copyright (c) 2006 Kris Beevers
*/

/*!
  \file mproshutdown.cpp
  \author Kris Beevers (beevek@cs.rpi.edu)
  \version $Id: mproshutdown.cpp,v 1.2 2006/02/09 01:42:21 beevek Exp $

  \brief Shut down the Magellan Pro.  Has no effect on a simulator.
 */

#include "options.hpp"
#include "mproclient.h"
#include "protocol.h"
#include <stdio.h>
#include <iostream>

extern server_type_t server_type;
extern int mpro_poweroff(void);

int main(int argc, char **argv)
{
  options::add<bool>("help", 0, "Print usage information", 0, false, options::nodump);
  options::add<std::string>("host", "h", "Hostname or IP address of server", 0,
			    "magellanpro.robotics.cs.rpi.edu");
  options::add<uint16_t>("port", "p", "Server port to connect to", 0, MPRO_PORT);

  // parse commandline
  int inpidx = options::parse_cmdline(argc, argv);
  if(inpidx < 0) // some kind of error
    return 1;    // relevant info printed by getopt

  // print usage information
  if(inpidx > argc || options::quickget<bool>("help") == true) {
    std::cerr << "Usage: " << argv[0] << " [options]" << std::endl;
    options::print_options(std::cout);
    return 1;
  }

  // connect to the server
  if(mpro_connect(options::quickget<std::string>("host").c_str(),
		  options::quickget<uint16_t>("port")) < 0) {
    perror("Failed connecting to server");
    return 1;
  }

  if(server_type != CONTROL) {
    printf("Server is not a real robot!\n");
    mpro_disconnect();
    return 1;
  }

  mpro_stop();
  mpro_poweroff();
  mpro_disconnect();

  return 0;
}
